# encoding: utf-8

from gvsig import *
from gvsig.commonsdialog import *
from gvsig.libs.toolbox import *
from es.unex.sextante.gui import core
from es.unex.sextante.gui.core import NameAndIcon, SextanteGUI
from org.gvsig.geoprocess.lib.api import GeoProcessLocator

class XYShift(ToolboxProcess):
    def defineCharacteristics(self):
        self.setName("Desplazamiento en X e Y")
        self.setGroup("Vectorial")
        params = self.getParameters()
        params.addInputVectorLayer("LAYER", "Capa de entrada", SHAPE_TYPE_POINT, True)
        params.addNumericalValue("X", "X_traslation",0, NUMERICAL_VALUE_DOUBLE)
        params.addNumericalValue("Y", "Y_traslation",0, NUMERICAL_VALUE_DOUBLE)
        self.addOutputVectorLayer("RESULT_POINT", "XYShift_point", SHAPE_TYPE_POINT)

    def processAlgorithm(self):
        features = None
        try:
            params = self.getParameters()
            layer = params.getParameterValueAsVectorLayer("LAYER")
            x = params.getParameterValueAsDouble("X")
            y = params.getParameterValueAsDouble("Y")
            input_store = layer.getFeatureStore()
            features = input_store.getFeatureSet()
            output_store = self.buildOutPutStore(
                features.getDefaultFeatureType(),
                SHAPE_TYPE_POINT,
                "XYShift_points",
                "RESULT_POINT"
                )
            self.setRangeOfValues(0, features.getSize())
            n = 0
            for feature in features.iterator():
                if self.isCanceled():
                    print "Proceso cancelado"
                    break
                newfeature = self.createNewFeature(output_store, feature)
                geom = newfeature.getDefaultGeometry()
                geom.move(x,y)
                output_store.insert(newfeature)
                n+=1
                self.setCurValue(n)
            output_store.finishEditing()
        finally:
            DisposeUtils.disposeQuietly(features)
            print "Proceso terminado %s" % self.getCommandLineName()
            return True

def main(*args):

    process = XYShift()
    process.selfregister("Scripting")
    gm = GeoProcessLocator.getGeoProcessManager()
    alg=gm.getAlgorithms()
    for a in alg:
        print a
    process.updateToolbox()
    msgbox("Script incorporado %s, %s" % (process.getGroup(), process.getName()))



        
